@@ -388,13 +388,12 @@ try_tls_conn_read(EV_P_ ev_io *w, int revents)
                 ptls_buffer_dispose(&hsbuf);
                 if (merged) Safefree(merged);
                 safe_close_conn(c, "TLS allocation failure");
-                return;
+                goto tls_read_cleanup;
             }
             int flush_ret = feer_tls_flush_wbuf(c);
             if (flush_ret == -1) {
                 /* Need to wait for write readiness */
-                SvREFCNT_inc_simple_void_NN(c->self);
-                ev_io_start(feersum_ev_loop, &c->write_ev_io);
+                feer_tls_start_write(c);
             }
         }
         ptls_buffer_dispose(&hsbuf);
