@@ -6,7 +6,7 @@ use EV ();
 use Carp ();
 use Socket ();
 
-our $VERSION = '1.506_07';
+our $VERSION = '1.506_08';
 
 require Feersum::Connection;
 require Feersum::Connection::Handle;
@@ -22,7 +22,7 @@ my %_SOCKETS; # inside-out storage for socket refs (keyed by Scalar::Util::refad
 
 use Scalar::Util ();
 use Exporter 'import';
-our @EXPORT_OK = qw(HEADER_NORM_UPCASE HEADER_NORM_LOCASE HEADER_NORM_UPCASE_DASH HEADER_NORM_LOCASE_DASH);
+our @EXPORT_OK = qw(HEADER_NORM_SKIP HEADER_NORM_UPCASE HEADER_NORM_LOCASE HEADER_NORM_UPCASE_DASH HEADER_NORM_LOCASE_DASH);
 
 sub new {
     unless ($INSTANCE) {
@@ -739,6 +739,14 @@ Defaults to 128.  Controls how long the name of each header can be.
 
 If a request exceeds this limit, a 400 response is given and the app handler does not run.
 
+=item MAX_URI_LEN
+
+Defaults to 8192.  Controls the maximum length of the request URI (including
+query string).
+
+If a request exceeds this limit, a 414 response is given and the app handler
+does not run.
+
 =item MAX_BODY_LEN
 
 Defaults to ~2GB.  Controls how large the body of a POST/PUT/etc. can be when
@@ -754,7 +762,7 @@ See also BUGS
 
 =item READ_GROW_FACTOR
 
-READ_BUFSZ defaults to 4096, READ_INIT_FACTOR 2 and READ_GROW_FACTOR 8.
+READ_BUFSZ defaults to 4096, READ_INIT_FACTOR 1 and READ_GROW_FACTOR 4.
 
 Together, these tune how data is read for a request.
 
@@ -773,10 +781,10 @@ option.  Set to 1 in Feersum.xs to enable event-loop-based writes.
 
 =item KEEPALIVE_CONNECTION
 
-Controls support of keepalive connections. Default is false.
-If enabled or set via Feersum->set_keepalive(1), then
-"Connection: keep-alive" for HTTP/1.0 and "Connection: close" for HTTP/1.1
-are acknowledged.
+Vestigial compile-time constant (default 0).  Keepalive is now controlled at
+runtime via C<< $server->set_keepalive(1) >>.  When enabled, "Connection:
+keep-alive" for HTTP/1.0 and "Connection: close" for HTTP/1.1 are
+acknowledged.
 
 =item READ_TIMEOUT
 
