@@ -156,10 +156,16 @@ The socket file-descriptor number for this connection.
 
 =item C<< $req->io >>
 
-Returns an L<IO::Socket::INET> handle for the underlying connection socket.
+Returns an L<IO::Handle> for the underlying connection socket (typically an
+L<IO::Socket::INET>).
 This is the native interface equivalent of C<psgix.io> in the PSGI environment.
 Any buffered request data will be pushed back into the socket's read buffer.
 
+For HTTP/2 Extended CONNECT streams (RFC 8441), this returns one end of a Unix
+socketpair instead of the raw TCP socket. Feersum shuttles data between the
+other end of the pair and H2 DATA frames internally. The handle is
+bidirectional and suitable for WebSocket or other tunnel protocols.
+
 B<WARNING>: Once you call this method, Feersum relinquishes control of the
 socket. You are responsible for all I/O and must not use other Feersum
 response methods on this connection.
@@ -225,13 +231,34 @@ One can export these constants via C<< use Feersum 'HEADER_NORM_LOCASE' >>
 
 simple lookup for header value, name should be in lowercase, eg. 'content-type'
 
-=item C<< my $env = $req->remote_address >>
+=item C<< my $addr = $req->remote_address >>
 
-remote address (psgi REMOTE_ADDR)
+Remote address of the connection (psgi REMOTE_ADDR). This always returns
+the actual socket peer address.
 
-=item C<< my $env = $req->remote_port >>
+=item C<< my $port = $req->remote_port >>
 
-remote port (psgi REMOTE_PORT)
+Remote port of the connection (psgi REMOTE_PORT).
+
+=item C<< my $addr = $req->client_address >>
+
+Client address, respecting reverse proxy mode. When C<reverse_proxy> is
+enabled and X-Forwarded-For header is present, returns the first (leftmost)
+IP from that header. Otherwise returns the same as C<remote_address>.
+
+=item C<< my $scheme = $req->url_scheme >>
+
+URL scheme (http or https), respecting reverse proxy mode. When
+C<reverse_proxy> is enabled and X-Forwarded-Proto header is present,
+returns that value. Otherwise returns "http".
+
+=item C<< my $tlvs = $req->proxy_tlvs >>
+
+Returns a hash reference of PROXY protocol v2 TLV (Type-Length-Value)
+extensions, or C<undef> if no TLVs were received. Keys are TLV type
+numbers (as integers), values are raw TLV data bytes. Only populated
+when C<proxy_protocol> is enabled and the client sends a v2 header
+with TLV extensions (e.g. PP2_TYPE_SSL, PP2_TYPE_AUTHORITY).
 
 =back
 
